@@ -9,14 +9,14 @@ class FilterMixin(object):
         """
         Returns an instance of the filterset to be used in this view.
         """
-        fs = self.filterset_class(**self.filterset_kwargs)
+        self.filterset = self.filterset_class(**self.filterset_kwargs)
 
         # filter out choices which have no result to avoid filter pollution
         # with choices which would empty out results
-        for name, field in fs.form.fields.items():
+        for name, field in self.filterset.form.fields.items():
             try:
                 mf = self.model._meta.get_field(name)
-            except:
+            except Exception:
                 continue
 
             if not isinstance(mf, models.ForeignKey):
@@ -26,13 +26,8 @@ class FilterMixin(object):
                 c=models.Count(mf.related_query_name())
             ).filter(c__gt=0)
 
-        return fs
-
-    def get_filterset_data_default(self):
-        return None
-
     def get_filterset_data(self):
-        return self.request.GET.copy() or self.get_filterset_data_default()
+        return self.request.GET.copy()
 
     def get_filterset_kwargs(self):
         """
@@ -75,14 +70,23 @@ class FilterMixin(object):
             fields=self.filter_fields,
             filter_overrides=self.filterset_meta_filter_overrides,
             form=self.filterset_form_class,
-            strict=django_filters.STRICTNESS.IGNORE,
         )
 
     def get_filterset_meta_class(self):
         return type('Meta', (object,), self.filterset_meta_attributes)
 
     def get_filterset_extra_class_attributes(self):
-        return dict()
+        extra = dict()
+        for field_name in self.filter_fields:
+            try:
+                field = self.model._meta.get_field(field_name)
+            except:  # noqa
+                continue
+            choices = getattr(field, 'choices', None)
+            if choices is None:
+                continue
+            extra[field_name] = django_filters.ChoiceFilter(choices=choices)
+        return extra
 
     def get_filterset_class_attributes(self):
         res = dict(Meta=self.filterset_meta_class)
